==> nhc98src-1.18.tar.gz: nhc98-1.18/src/prelude/List/LookupBy.p.c <==
#include "newmacros.h"
#include "runtime.h"

#define v186	((void*)startLabel+22)
#define v187	((void*)startLabel+32)
#define v192	((void*)startLabel+62)
#define v194	((void*)startLabel+83)
#define v188	((void*)startLabel+88)
#define v183	((void*)startLabel+93)
#define CT_v204	((void*)startLabel+268)
#define FN_LAMBDA181	((void*)startLabel+320)
#define CT_v208	((void*)startLabel+364)
#define CF_LAMBDA181	((void*)startLabel+372)
#define ST_v197	((void*)startLabel+392)
#define PP_LAMBDA181	((void*)startLabel+406)
#define PC_LAMBDA181	((void*)startLabel+406)
#define ST_v206	((void*)startLabel+406)
#define ST_v207	((void*)startLabel+429)
#define PS_v203	((void*)startLabel+484)
#define PS_v199	((void*)startLabel+496)
#define PS_v201	((void*)startLabel+508)
#define PS_v196	((void*)startLabel+520)
#define PS_v202	((void*)startLabel+532)
#define PS_v205	((void*)startLabel+544)
extern Node CF_Prelude_46otherwise[];
extern Node FN_Prelude_46error[];
extern Node PM_List[];
extern Node PC_Prelude_46error[];
extern Node PC_Prelude_46Nothing[];
extern Node PC_Prelude_46Just[];

static Node startLabel[] = {
  bytes2word(3,0,2,1)
, bytes2word(1,2,0,3)
, useLabel(CT_v204)
,};
Node FN_List_46lookupBy[] = {
  bytes2word(NEEDSTACK_I16,PUSH_ZAP_ARG_I3,EVAL,NEEDHEAP_I32)
, bytes2word(TABLESWITCH,2,TOP(4),BOT(4))
,	/* v186: (byte 2) */
  bytes2word(TOP(14),BOT(14),POP_I1,PUSH_HEAP)
, bytes2word(HEAP_CVAL_N1,7,HEAP_CVAL_N1,12)
,	/* v187: (byte 4) */
  bytes2word(HEAP_CREATE,HEAP_SPACE,HEAP_SPACE,RETURN)
, bytes2word(UNPACK,2,PUSH_P1,0)
, bytes2word(EVAL,UNPACK,2,PUSH_P1)
, bytes2word(0,PUSH_ARG_I2,PUSH_ARG_I1,EVAL)
, bytes2word(NEEDHEAP_I32,APPLY,2,EVAL)
, bytes2word(NEEDHEAP_I32,JUMPFALSE,12,0)
, bytes2word(PUSH_HEAP,HEAP_CVAL_N1,17,HEAP_CVAL_N1)
, bytes2word(22,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
,	/* v192: (byte 2) */
  bytes2word(HEAP_I2,RETURN,PUSH_CVAL_P1,7)
, bytes2word(EVAL,NEEDHEAP_I32,JUMPFALSE,16)
, bytes2word(0,PUSH_HEAP,HEAP_CVAL_P1,8)
, bytes2word(HEAP_CVAL_N1,27,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,HEAP_ARG_ARG,1,2)
,	/* v194: (byte 3) */
  bytes2word(HEAP_P1,4,RETURN_EVAL,POP_P1)
,	/* v188: (byte 4) */
  bytes2word(2,JUMP,2,0)
, bytes2word(POP_P1,2,JUMP,2)
,	/* v183: (byte 1) */
  bytes2word(0,HEAP_CVAL_P1,9,HEAP_CVAL_N1)
, bytes2word(32,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(PUSH_HEAP,HEAP_CVAL_P1,10,HEAP_CVAL_N1)
, bytes2word(37,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(HEAP_OFF_N1,10,RETURN_EVAL,ENDCODE)
, bytes2word(0,0,0,0)
, 0
, useLabel(PS_v203)
, 0
, 0
, 0
, 0
, useLabel(PS_v202)
, 0
, 0
, 0
, 0
, useLabel(PS_v196)
, 0
, 0
, 0
, 0
, useLabel(PS_v201)
, 0
, 0
, 0
, 0
, CONSTR(1,1,0)
, 0
, 0
, 0
, 0
, useLabel(PS_v199)
, 0
, 0
, 0
, 0
, CONSTR(0,0,0)
, 0
, 0
, 0
, 0
, 40001
, useLabel(ST_v197)
,	/* CT_v204: (byte 0) */
  HW(4,3)
, 0
,};
Node F0_List_46lookupBy[] = {
  CAPTAG(useLabel(FN_List_46lookupBy),3)
, useLabel(PS_v196)
, 0
, 0
, 0
, useLabel(CF_Prelude_46otherwise)
, VAPTAG(useLabel(FN_List_46lookupBy))
, VAPTAG(useLabel(FN_LAMBDA181))
, VAPTAG(useLabel(FN_Prelude_46error))
, bytes2word(0,0,0,0)
, useLabel(CT_v208)
,	/* FN_LAMBDA181: (byte 0) */
  bytes2word(NEEDHEAP_I32,PUSH_CADR_N1,8,STRING)
, bytes2word(RETURN,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, CONSTRW(1,0)
, 0
, 0
, 0
, 0
, useLabel(ST_v207)
, 40001
, useLabel(ST_v206)
,	/* CT_v208: (byte 0) */
  HW(0,0)
, 0
,	/* CF_LAMBDA181: (byte 0) */
  VAPTAG(useLabel(FN_LAMBDA181))
, useLabel(PS_v205)
, 0
, 0
, 0
,};
Node PP_List_46lookupBy[] = {
 };
Node PC_List_46lookupBy[] = {
 	/* ST_v197: (byte 0) */
  bytes2word(76,105,115,116)
, bytes2word(46,108,111,111)
, bytes2word(107,117,112,66)
,	/* PP_LAMBDA181: (byte 2) */
 	/* PC_LAMBDA181: (byte 2) */
 	/* ST_v206: (byte 2) */
  bytes2word(121,0,76,105)
, bytes2word(115,116,46,108)
, bytes2word(111,111,107,117)
, bytes2word(112,66,121,58)
, bytes2word(52,58,49,45)
, bytes2word(55,58,52,54)
,	/* ST_v207: (byte 1) */
  bytes2word(0,76,105,115)
, bytes2word(116,58,32,80)
, bytes2word(97,116,116,101)
, bytes2word(114,110,32,109)
, bytes2word(97,116,99,104)
, bytes2word(32,102,97,105)
, bytes2word(108,117,114,101)
, bytes2word(32,105,110,32)
, bytes2word(102,117,110,99)
, bytes2word(116,105,111,110)
, bytes2word(32,97,116,32)
, bytes2word(52,58,49,45)
, bytes2word(55,58,52,54)
, bytes2word(46,0,0,0)
,	/* PS_v203: (byte 0) */
  useLabel(PM_List)
, useLabel(PP_List_46lookupBy)
, useLabel(PC_Prelude_46error)
,	/* PS_v199: (byte 0) */
  useLabel(PM_List)
, useLabel(PP_List_46lookupBy)
, useLabel(PC_Prelude_46Nothing)
,	/* PS_v201: (byte 0) */
  useLabel(PM_List)
, useLabel(PP_List_46lookupBy)
, useLabel(PC_Prelude_46Just)
,	/* PS_v196: (byte 0) */
  useLabel(PM_List)
, useLabel(PP_List_46lookupBy)
, useLabel(PC_List_46lookupBy)
,	/* PS_v202: (byte 0) */
  useLabel(PM_List)
, useLabel(PP_List_46lookupBy)
, useLabel(PC_LAMBDA181)
,	/* PS_v205: (byte 0) */
  useLabel(PM_List)
, useLabel(PP_LAMBDA181)
, useLabel(PC_LAMBDA181)
,};

==> nhc98src-1.20.tar.gz: nhc98-1.20/src/prelude/List/LookupBy.p.c <==
#include "newmacros.h"
#include "runtime.h"

#define v191	((void*)startLabel+22)
#define v192	((void*)startLabel+32)
#define v197	((void*)startLabel+62)
#define v199	((void*)startLabel+83)
#define v193	((void*)startLabel+88)
#define v188	((void*)startLabel+93)
#define CT_v209	((void*)startLabel+268)
#define FN_LAMBDA186	((void*)startLabel+320)
#define CT_v213	((void*)startLabel+364)
#define CF_LAMBDA186	((void*)startLabel+372)
#define ST_v202	((void*)startLabel+392)
#define PP_LAMBDA186	((void*)startLabel+406)
#define PC_LAMBDA186	((void*)startLabel+406)
#define ST_v211	((void*)startLabel+406)
#define ST_v212	((void*)startLabel+429)
#define PS_v208	((void*)startLabel+484)
#define PS_v204	((void*)startLabel+496)
#define PS_v206	((void*)startLabel+508)
#define PS_v201	((void*)startLabel+520)
#define PS_v207	((void*)startLabel+532)
#define PS_v210	((void*)startLabel+544)
extern Node CF_Prelude_46otherwise[];
extern Node FN_NHC_46Internal_46_95patternMatchFail[];
extern Node PM_List[];
extern Node PC_NHC_46Internal_46_95patternMatchFail[];
extern Node PC_Prelude_46Nothing[];
extern Node PC_Prelude_46Just[];

static Node startLabel[] = {
  bytes2word(3,0,2,1)
, bytes2word(1,2,0,3)
, useLabel(CT_v209)
,};
Node FN_List_46lookupBy[] = {
  bytes2word(NEEDSTACK_I16,PUSH_ZAP_ARG_I3,EVAL,NEEDHEAP_I32)
, bytes2word(TABLESWITCH,2,TOP(4),BOT(4))
,	/* v191: (byte 2) */
  bytes2word(TOP(14),BOT(14),POP_I1,PUSH_HEAP)
, bytes2word(HEAP_CVAL_N1,7,HEAP_CVAL_N1,12)
,	/* v192: (byte 4) */
  bytes2word(HEAP_CREATE,HEAP_SPACE,HEAP_SPACE,RETURN)
, bytes2word(UNPACK,2,PUSH_P1,0)
, bytes2word(EVAL,UNPACK,2,PUSH_P1)
, bytes2word(0,PUSH_ARG_I2,PUSH_ARG_I1,EVAL)
, bytes2word(NEEDHEAP_I32,APPLY,2,EVAL)
, bytes2word(NEEDHEAP_I32,JUMPFALSE,12,0)
, bytes2word(PUSH_HEAP,HEAP_CVAL_N1,17,HEAP_CVAL_N1)
, bytes2word(22,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
,	/* v197: (byte 2) */
  bytes2word(HEAP_I2,RETURN,PUSH_CVAL_P1,7)
, bytes2word(EVAL,NEEDHEAP_I32,JUMPFALSE,16)
, bytes2word(0,PUSH_HEAP,HEAP_CVAL_P1,8)
, bytes2word(HEAP_CVAL_N1,27,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,HEAP_ARG_ARG,1,2)
,	/* v199: (byte 3) */
  bytes2word(HEAP_P1,4,RETURN_EVAL,POP_P1)
,	/* v193: (byte 4) */
  bytes2word(2,JUMP,2,0)
, bytes2word(POP_P1,2,JUMP,2)
,	/* v188: (byte 1) */
  bytes2word(0,HEAP_CVAL_P1,9,HEAP_CVAL_N1)
, bytes2word(32,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(PUSH_HEAP,HEAP_CVAL_P1,10,HEAP_CVAL_N1)
, bytes2word(37,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(HEAP_OFF_N1,10,RETURN_EVAL,ENDCODE)
, bytes2word(0,0,0,0)
, 0
, useLabel(PS_v208)
, 0
, 0
, 0
, 0
, useLabel(PS_v207)
, 0
, 0
, 0
, 0
, useLabel(PS_v201)
, 0
, 0
, 0
, 0
, useLabel(PS_v206)
, 0
, 0
, 0
, 0
, CONSTR(1,1,0)
, 0
, 0
, 0
, 0
, useLabel(PS_v204)
, 0
, 0
, 0
, 0
, CONSTR(0,0,0)
, 0
, 0
, 0
, 0
, 40001
, useLabel(ST_v202)
,	/* CT_v209: (byte 0) */
  HW(4,3)
, 0
,};
Node F0_List_46lookupBy[] = {
  CAPTAG(useLabel(FN_List_46lookupBy),3)
, useLabel(PS_v201)
, 0
, 0
, 0
, useLabel(CF_Prelude_46otherwise)
, VAPTAG(useLabel(FN_List_46lookupBy))
, VAPTAG(useLabel(FN_LAMBDA186))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95patternMatchFail))
, bytes2word(0,0,0,0)
, useLabel(CT_v213)
,	/* FN_LAMBDA186: (byte 0) */
  bytes2word(NEEDHEAP_I32,PUSH_CADR_N1,8,STRING)
, bytes2word(RETURN,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, CONSTRW(1,0)
, 0
, 0
, 0
, 0
, useLabel(ST_v212)
, 40001
, useLabel(ST_v211)
,	/* CT_v213: (byte 0) */
  HW(0,0)
, 0
,	/* CF_LAMBDA186: (byte 0) */
  VAPTAG(useLabel(FN_LAMBDA186))
, useLabel(PS_v210)
, 0
, 0
, 0
,};
Node PP_List_46lookupBy[] = {
 };
Node PC_List_46lookupBy[] = {
 	/* ST_v202: (byte 0) */
  bytes2word(76,105,115,116)
, bytes2word(46,108,111,111)
, bytes2word(107,117,112,66)
,	/* PP_LAMBDA186: (byte 2) */
 	/* PC_LAMBDA186: (byte 2) */
 	/* ST_v211: (byte 2) */
  bytes2word(121,0,76,105)
, bytes2word(115,116,46,108)
, bytes2word(111,111,107,117)
, bytes2word(112,66,121,58)
, bytes2word(52,58,49,45)
, bytes2word(55,58,52,54)
,	/* ST_v212: (byte 1) */
  bytes2word(0,76,105,115)
, bytes2word(116,58,32,80)
, bytes2word(97,116,116,101)
, bytes2word(114,110,32,109)
, bytes2word(97,116,99,104)
, bytes2word(32,102,97,105)
, bytes2word(108,117,114,101)
, bytes2word(32,105,110,32)
, bytes2word(102,117,110,99)
, bytes2word(116,105,111,110)
, bytes2word(32,97,116,32)
, bytes2word(52,58,49,45)
, bytes2word(55,58,52,54)
, bytes2word(46,0,0,0)
,	/* PS_v208: (byte 0) */
  useLabel(PM_List)
, useLabel(PP_List_46lookupBy)
, useLabel(PC_NHC_46Internal_46_95patternMatchFail)
,	/* PS_v204: (byte 0) */
  useLabel(PM_List)
, useLabel(PP_List_46lookupBy)
, useLabel(PC_Prelude_46Nothing)
,	/* PS_v206: (byte 0) */
  useLabel(PM_List)
, useLabel(PP_List_46lookupBy)
, useLabel(PC_Prelude_46Just)
,	/* PS_v201: (byte 0) */
  useLabel(PM_List)
, useLabel(PP_List_46lookupBy)
, useLabel(PC_List_46lookupBy)
,	/* PS_v207: (byte 0) */
  useLabel(PM_List)
, useLabel(PP_List_46lookupBy)
, useLabel(PC_LAMBDA186)
,	/* PS_v210: (byte 0) */
  useLabel(PM_List)
, useLabel(PP_LAMBDA186)
, useLabel(PC_LAMBDA186)
,};
